<?php
/**
 * The Faq script to delete categories.
 *
 * Copyright 2003 Aleksandar Markovic <mikikg@ptt.yu>
 * Copyright 2003 Oblo Project <info@oblo.com>
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/faq/LICENSE.
 *
 * $Horde: faq/categories/delete.php,v 1.27 2006/08/04 15:33:12 duck Exp $
 */

@define('FAQ_BASE', dirname(__FILE__) . '/..');
require_once FAQ_BASE . '/lib/base.php';

require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Form.php';

/* Only admins should be using this. */
if (!Auth::isAdmin()) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

$vars = &Variables::getDefaultVariables();
if (($cid = $vars->get('cid')) == DATATREE_ROOT) {
    $notification->push(_("No valid category specified for deletion."));
    $url = Horde::applicationUrl('categories/index.php', true);
    header('Location: ' . $url);
    exit;
}

$form = new Horde_Form($vars, sprintf(_("Delete category \"%s\" and any subcategories?"), $faq_cat->getName($cid)), 'delete');
$form->setButtons(array(_("Remove"), _("Cancel")));
$form->addHidden('', 'cid', 'text', $cid);

if ($form->validate($vars) && Util::getFormData('submitbutton') == _("Remove")) {
    $result = $faq->removeByCategory($cid);
    if (is_a($result, 'PEAR_Error')) {
        $notification->push($result->getMessage() . ': ' . $result->getDebugInfo(), 'horde.error');
    }

    header('Location: ' . Horde::applicationUrl('categories/index.php'));
    exit;
}

/* Set up the template fields. */
$template = new Horde_Template();
$template->setoption('gettext', true);
$template->set('menu', Faq::getMenu('string'));
$template->set('form', Util::bufferOutput(array($form, 'renderActive'), new Horde_Form_Renderer(), $vars, 'delete.php', 'post'));
$template->set('tree', Util::bufferOutput(array($faq_cat, 'renderTree'), $cid));
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

$title = _("Category Administration");
require FAQ_BASE . '/templates/common-header.inc';
echo $template->fetch(FAQ_TEMPLATES . '/categories/delete.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
