<?php
/**
 * The Faq script to edit categories.
 *
 * Copyright 2003 Aleksandar Markovic <mikikg@ptt.yu>
 * Copyright 2003 Oblo Project <info@oblo.com>
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/faq/LICENSE.
 *
 * $Horde: faq/categories/edit.php,v 1.24 2006/08/04 15:33:12 duck Exp $
 */

@define('FAQ_BASE', dirname(__FILE__) . '/..');
require_once FAQ_BASE . '/lib/base.php';

require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Form.php';
require_once 'Horde/MIME/Magic.php';
require_once 'Horde/MIME/Viewer.php';
require_once 'Horde/MIME/Part.php';

/* Only admins should be using this. */
if (!Auth::isAdmin()) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$title = _("Add a category");
$vars = Variables::getDefaultVariables();
$cid = $vars->get('cid');
$parent_cid = $vars->get('parent_cid');
$form = new Horde_Form($vars);

/* Check if a category is being edited. */
$editing = false;
if ($cid) {
    $editing = true;
    $use_cid = $cid;
    if (!$form->isSubmitted()) {
        $vars = new Variables($faq_cat->getCatArray($cid));
    }
} elseif ($parent_cid) {
    $use_cid = $parent_cid;
} else {
    $use_cid = DATATREE_ROOT;
}

/* Slightly change the title whether root category or subcategory. */
if ($use_cid != DATATREE_ROOT) {
    $title = sprintf(_("Add a subcategory to \"%s\""), $faq_cat->getName($use_cid));
}

/* Set up form. */
$form->setTitle(($editing ? _("Edit Category") : $title));
$form->addHidden('', 'cid', 'text', $cid);
$form->addHidden('', 'parent_cid', 'text', $parent_cid);
$form->addHidden('', 'current_image', 'text', $vars->get('current_image'));
$form->addVariable(_("Image"), 'image', 'image', false);

/* Add category name fields for all languages. */
foreach ($conf['languages'] as $lang_name) {
    $flag = (count($conf['languages']) > 1) ? Faq::getFlag($lang_name) . ' ' : '';
    $form->addVariable($flag . _("Name"), 'name[' . $lang_name . ']', 'text', true);
}

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $result = $faq_cat->save($info);
    if (is_a($result, 'PEAR_Error')) {
        $notification->push($result->getMessage() . ': ' . $result->getDebugInfo(), 'horde.error');
    } else {
        $notification->push(sprintf(_("Category succesfully saved.")));
        $url = Horde::applicationUrl('categories/index.php', true);
        header('Location: ' . $url);
        exit;
    }
}

/* Set up the template fields. */
$template = new Horde_Template();
$template->setoption('gettext', true);
$template->set('menu', Faq::getMenu('string'));
$template->set('form',Util::bufferOutput(array($form, 'renderActive'), new Horde_Form_Renderer(), $vars, 'edit.php', 'post'));
$template->set('tree', Util::bufferOutput(array($faq_cat, 'renderTree'), $cid));
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

require FAQ_BASE . '/templates/common-header.inc';
echo $template->fetch(FAQ_TEMPLATES . '/categories/edit.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
