<?php
/**
 * Faq Base Class.
 *
 * $Horde: faq/lib/Faq.php,v 1.15 2006/03/07 18:17:34 slusarz Exp $
 *
 * Copyright 2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Faq
 */
class Faq {

    /**
     * Returns a flag image for a language.
     *
     * @param string $lang  The language to return the flag for, e.g. 'en_US'.
     */
    function getFlag($lang)
    {
        $flag = 'flags/' . strtolower(substr($lang, -2)) . '.png';
        return Horde::img($flag, $lang, 'align="middle"', $GLOBALS['registry']->getImageDir('horde'));
    }

    /**
     * Returns the current language
     *
     * @return string  The current language.
     */
    function getLang()
    {
        static $lang;

        if ($lang === null) {
            $lang = NLS::Select();
            if (!in_array($lang, $GLOBALS['conf']['languages'])) {
                $lang = $GLOBALS['conf']['languages'][0];
            }
        }
        
        return $lang;
    }

    /**
     * Build Faq's list of menu items.
     */
    function getMenu($returnType = 'object')
    {
        global $conf, $registry, $browser, $print_link;

        require_once 'Horde/Menu.php';
        $img = $GLOBALS['registry']->getImageDir('horde');

        $menu = &new Menu(HORDE_MENU_MASK_ALL);
        $menu->add(Horde::applicationUrl('list.php'), _("List"), 'user.png', $img);

        if (Auth::isAdmin('faq')) {
            $menu->add(Horde::applicationUrl('questions/index.php'), _("Questions"), 'datatree.png', $img);
            $menu->add(Horde::applicationUrl('categories/index.php'), _("Categories"), 'category.png', $img);
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}

/**
 * Faq_Driver:: defines an API for implementing storage backends for Faq.
 *
 * $Horde: faq/lib/Driver.php,v 1.14 2006/08/05 21:30:01 chuck Exp $
 *
 * Copyright 2004-2006 Duck <duck@obala.net>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Duck <duck@obala.net>
 * @package Faq
 */
class Faq_Driver {

    /**
     * Attempts to return a concrete Faq_Driver instance based on $driver.
     *
     * @param string $driver  The type of the concrete Faq_Driver subclass
     *                        to return.  The class name is based on the
     *                        storage driver ($driver).  The code is
     *                        dynamically included.
     *
     * @param array $params   A hash containing any additional configuration
     *                        or connection parameters a subclass might need.
     *
     * @return Faq_Driver  The newly created concrete Faq_Driver
     *                          instance, or false on an error.
     */
    function factory($driver = null, $params = null)
    {
        if ($driver === null) {
            $driver = $GLOBALS['conf']['storage']['driver'];
        }
        $driver = basename($driver);

        if ($params === null) {
            $params = Horde::getDriverConfig('storage', $driver);
        }

        $class = 'Faq_Driver_' . $driver;
        if (!class_exists($class)) {
            include dirname(__FILE__) . '/Driver/' . $driver . '.php';
        }
        if (class_exists($class)) {
            return new $class($params);
        } else {
            return false;
        }
    }

}
